@@ -108,6 +108,105 @@ class ModelField(object):
         return self.dumps()
 
 
+class ListField(ModelField):
+
+    def __init__(self, **kwargs):
+        """
+        """
+
+        super(ListField, self).__init__(**kwargs)
+
+        # If null is allowed, default value is None
+        if self.null and self.default is None:
+            self.saved_list = None
+        else:
+            # If default value was set
+            if not self.default is None:
+                self.saved_list = self.default
+            else:
+                self.saved_list = []
+
+
+    def dumps(self):
+        """
+        """
+
+        json_save_list = []
+        for saved_entry in self.saved_list:
+            is_number =  isinstance(saved_entry, int) or isinstance(saved_entry, float)
+
+            # Check if entry is base type
+            if isinstance(saved_entry, basestring) or is_number or isinstance(saved_entry, bool):
+                json_save_list.append(saved_entry)
+            else:
+                json_save_list.append(self._get_json_save_value(saved_entry))
+
+
+        return json_save_list
+
+    def _get_json_save_value(self, value):
+        """
+        """
+
+        if isinstance(value, list) or isinstance(value, tuple):
+            return value
+
+        if isinstance(value, dict):
+            return value
+
+        else:
+            return u'%s' % value
+
+    def loads(self, saved_list):
+        """
+        """
+
+        self.saved_list = saved_list
+
+    def validate(self):
+        """
+        """
+
+        if self.saved_list is None and self.null is False:
+            raise ListField.NotNullableFieldException()
+
+    def set(self, *args, **kwargs):
+        """
+        """
+
+        if len(args) is 1:
+            saved_list = args[0]
+
+            if saved_list is None and self.null is False:
+                raise ListField.NotNullableFieldException()
+
+            if isinstance(saved_list, list) or isinstance(saved_list, tuple):
+                self.saved_list = saved_list
+            else:
+                self.saved_list = args
+
+    def get(self):
+        """
+        """
+
+        if self.saved_list is None and self.null is False:
+            self.saved_list = []
+
+        return self.saved_list
+
+    def __eq__(self, other):
+        """
+        """
+
+        return super(ListField, self).__eq__(other)
+
+    def __unicode__(self):
+        """
+        """
+
+        return self.dumps()
+
+
 class BooleanField(ModelField):
 
     def __init__(self, **kwargs):
@@ -449,10 +548,13 @@ class DatetimeField(ModelField):
         """
         """
 
-        if self.time and not self.null:
-            return u'%s' % self.time.strftime(DatetimeField.DATE_FORMAT)
-        else:
+        if self.null and self.time is None:
             return None
+        else:
+            if self.time is None:
+                raise Exception('Datetime cannot be None')
+            else:
+                return u'%s' % self.time.strftime(DatetimeField.DATE_FORMAT)
 
     def loads(self, date_string):
         """
@@ -516,10 +618,13 @@ class DateField(ModelField):
         """
         """
 
-        if self.date and not self.null:
-            return u'%s' % self.date.strftime(DateField.DATE_FORMAT)
-        else:
+        if self.null and self.date is None:
             return None
+        else:
+            if self.date is None:
+                raise Exception('Datetime cannot be None')
+            else:
+                return u'%s' % self.date.strftime(DateField.DATE_FORMAT)
 
     def loads(self, date_string):
         """
